@@ -52,7 +52,7 @@ class RequestTest(TestBase):
             req.run()
             data = f.read()
             self.assertIn(
-                b'curl "https://req.dothttp.dev/" \\\n    -X GET \\\n    -H "connection: Keep-Alive" \\\n    -H ',
+                b'curl -X GET "https://req.dothttp.dev/" \\\n    -H "connection: Keep-Alive" \\\n    -H ',
                 data
             )
 
@@ -67,8 +67,8 @@ class RequestTest(TestBase):
     def test_curl_print(self):
         req: CurlCompiler = self.get_req_comp(f"{base_dir}/redirect.http", info=True, curl=True)
         output = req.get_curl_output()
-        self.assertEqual("""curl -X GET \\
-http://endeavour.today/""", output)
+        self.assertEqual("""curl -X GET http://endeavour.today/ \\
+""", output)
 
     def test_format_print(self):
         req = self.get_req_comp(f"{base_dir}/redirect.http", format=True, stdout=True)
@@ -112,56 +112,49 @@ output(test)
     def test_multiline_curl(self):
         with tempfile.NamedTemporaryFile(delete=False) as f:
             # with files
-            self.assertEqual(f'''curl -X POST \\
+            self.assertEqual(f'''curl -X POST https://httpbin.org/post \\
 --form 'test=@{f.name}' \\
---form hi=hi2 \\
-https://httpbin.org/post''', self.get_curl_out(f))
+--form hi=hi2''', self.get_curl_out(f))
 
             # with file input
-            self.assertEqual(f'''curl -X POST \\
---data '@{f.name}' \\
-https://httpbin.org/post''', self.get_curl_out(f, 2))
+            self.assertEqual(f"""curl -X POST https://httpbin.org/post \\
+--data '@{f.name}'""", self.get_curl_out(f, 2))
 
             # with json out
-            self.assertEqual('''curl -X POST \\
+            self.assertEqual("""curl -X POST https://httpbin.org/post \\
 -H 'Content-Length: 19' \\
 -H 'content-type: application/json' \\
 -d '{
     "hi": "hi2"
-}' \\
-https://httpbin.org/post''', self.get_curl_out(f, 3))
+}'""", self.get_curl_out(f, 3))
 
     @unittest.skipUnless(sys.platform.startswith("linux"), "requires linux")
     def test_multiline_curl_linux(self):
         with tempfile.NamedTemporaryFile(delete=False) as f:
             # with files
-            self.assertEqual(f'''curl -X POST \\
+            self.assertEqual(f'''curl -X POST https://httpbin.org/post \\
 --form test=@{f.name} \\
---form hi=hi2 \\
-https://httpbin.org/post''', self.get_curl_out(f))
+--form hi=hi2''', self.get_curl_out(f))
 
             # with file input
-            self.assertEqual(f'''curl -X POST \\
---data @{f.name} \\
-https://httpbin.org/post''', self.get_curl_out(f, 2))
+            self.assertEqual(f'''curl -X POST https://httpbin.org/post \\
+--data @{f.name}''', self.get_curl_out(f, 2))
 
             # with json out
-            self.assertEqual('''curl -X POST \\
+            self.assertEqual("""curl -X POST https://httpbin.org/post \\
 -H 'Content-Length: 19' \\
 -H 'content-type: application/json' \\
 -d '{
     "hi": "hi2"
-}' \\
-https://httpbin.org/post''', self.get_curl_out(f, 3))
+}'""", self.get_curl_out(f, 3))
 
-            self.assertEqual('''curl -X POST \\
+            self.assertEqual("""curl -X POST https://httpbin.org/post \\
 -H 'Content-Length: 52' \\
 -H 'content-type: text/xml' \\
 -d '<xml>
     <body> hi this is test body</body>
 </xml>
-' \\
-https://httpbin.org/post''', self.get_curl_out(f, 4))
+'""", self.get_curl_out(f, 4))
 
     def get_curl_out(self, f, target=1):
         comp2 = self.get_req_comp(f'{base_dir}/curlgen.http', curl=True, properties=[f"filename={f.name}"],
